function model=calibration(file,PKTS,CLUSTERS)
%	calibration	Find the model with the best parameters to model a traingin set
%
%	Description
%	MODEL=calibration(FILE,PKTS,CLUSTERS) takes as input a file (FILE)  containing a series of connections 
%	and vectors of packets and clusters to consider in the model (PKT, CLUSTERS)
%
%	Each connection is described in one line with the following syntax:
%	appname	dport	pkt1	pkt2	...	pktN
%	
%	appname is the name of the application that generated a connection
%	dport is the server port used in the TCP connection
%	pkt1 ... pktN are the payload sizes of the TCP packets which have a payload.
%
%	For better results a similar number of connections should be used for each application
%
%	The output MODEL is a description of the behaviors found in the training set
%

	TH=0.98;
	%TH: to find the knee in NMIs curves.
	%TH=1: find number of clusters that maximizes NMI
	%TH=X: find the minimum number of cluster with NMI >= to X*max(NMI)

	for p=1:length(PKTS)
		fprintf('Calibration Model: Iteration %d/%d\n',p,length(PKTS));
		fprintf('\tSearching best number of clusters for %d packets\n',PKTS(p));
		for k=1:length(CLUSTERS)
			iter(k)=modelBehaviors(file,PKTS(p),CLUSTERS(k));
			nmis(k)=iter(k).nmi;
		end
		idx=min(find(nmis>=max(nmis)*TH));
		fprintf('\tBest number of clusters for %d packets : %d\n\n',PKTS(p),CLUSTERS(idx));
		iterpkt(p)=iter(idx);
		nmispkts(p)=iter(idx).nmi;
	end
	[void idx]=max(nmispkts);
	fprintf('Model Calibrated. Best parameters: %d Packets and %d Clusters%d',PKTS(idx),iterpkt(idx).clusters);

	model=iterpkt(idx);
end
