function labels = label(model,file,th)
%	label: Label connections using a model
%
%	Description
%	LABELS = label(MODEL,FILE,TH) takes as input a model (obtained from modelBehaviors)
%		and labels the connections in FILE based on the sizes of the first model.pkts packets
%		TH specifies a threshold for cluster assignment (0<=TH<=1; TH=0: no thresholds)
%
%	Each connection is described in one line with the following syntax:
%	dport	pkt1	pkt2	...	pktN
%
%	The output is a structure LABELS with fields:
%		Mapping: The cluster to which each connection was assigned (0: unknown)
%		Dominant: The application for each connection using the dominant heuristic
%		ClusterPorts: The application for each connection using the Cluster+Port heuristic
%		Test: labeled connections



	addpath('netlab');

	pkts=model.pkts;
	switch (pkts)
		case 1
			[dport p1]=textread(file,'%d\t%d%*[^\n]');
			seq=[p1];
		case 2
			[dport p1 p2]=textread(file,'%d\t%d\t%d%*[^\n]');
			seq=[p1 p2];
		case 3
			[dport p1 p2 p3]=textread(file,'%d\t%d\t%d\t%d%*[^\n]');
			seq=[p1 p2 p3];
		case 4
			[dport p1 p2 p3 p4]=textread(file,'%d\t%d\t%d\t%d\t%d%*[^\n]');
			seq=[p1 p2 p3 p4];
		case 5
			[dport p1 p2 p3 p4 p5]=textread(file,'%d\t%d\t%d\t%d\t%d\t%d%*[^\n]');
			seq=[p1 p2 p3 p4 p5];
	end

	
	[probas mapping]=max(gmmlactiv(model.gmm,seq),[],2);	
	knownIdx=find(probas>=th);
	unknownIdx=find(probas<=th);

	mapping(unknownIdx)=0;

% Dominant Analysis
	Class(knownIdx)=model.labelDom(mapping(knownIdx));
	Class=Class';

	tmp=model.Applis;
	tmp(end+1)={'Unknown'};
	Class(unknownIdx)=length(tmp);
	
	labels.Dominant=tmp(Class);
	labels.Mapping=mapping;

% Port analysis
	idxPort=zeros(length(knownIdx),1);
	for i=1:length(knownIdx)
		idx=find(model.knownports==dport(knownIdx(i)));
		if (length(idx)>0)
			idxPort(i)=idx;
		end
	end
		
	Class=zeros(length(dport),1);

	if (length(knownIdx)>0)
		idxPortOK=find(idxPort>0);
		idxPortKO=find(idxPort==0);

		for f=1:length(idxPortOK)
			Class(knownIdx(idxPortOK(f)))=model.appFromPort(mapping(knownIdx(idxPortOK(f))),idxPort(idxPortOK(f)));
		end
		Class(knownIdx(idxPortKO))=model.DominantUnStd(mapping(knownIdx(idxPortKO)));

	end

	Class(unknownIdx)=length(tmp);
	masquerade=find(Class<0);
	tmp(end+1)={'Masquerade'};
	Class(masquerade)=length(tmp);
	labels.ClusterPorts=tmp(Class);

	labels.Test.dport=dport;
	labels.Test.seq=seq;
	labels.Unknown=1-length(knownIdx)/length(dport);

end
