function c = nmi(x,y)
% c = nmi(x,y)
%
% computes Normalized Mutual Information between X and Y
%
% Inputs should be column vectors of the same size.
% Elements of X and Y must be integers and must be
% 'continuous', e.g.
%  unique(X) = [1 2 3 4 5 6] and unique(Y) = [1 2 3 4]
% 
% 


% make sure these are column vectors
if(size(x,1) == 1)
	x = x' ;
end
if(size(y,1) == 1)
	y = y' ;
end

if(size(x,1) ~= size(y,1))
	error('Inputs should have the same sizes');
end

%%%%%%%%%%%%%%%%%%%%%%%%%%
% action
%%%%%%%%%%%%%%%%%%%%%%%%%%

eltx=unique(x);
elty=unique(y);
lx = length(eltx);
ly = length(elty);
n = size(x,1);

% counts
nx = [] ; ny = [] ; nxy = [] ;
for ii=1:lx
	nx(ii) = length(find(x == eltx(ii))) ;
end

for jj=1:ly
	ny(jj) = length(find(y == elty(jj))) ;
end

for ii=1:lx
	for jj=1:ly
		nxy(ii,jj) = length(find(and((x==eltx(ii)),(y==elty(jj))))) ;
	end
end
c = 0 ;

% mutual info & entropies

hx = sum(nx .* log(nx/n)) ;

hy = sum(ny .* log(ny/n)) ;

ixy = 0 ;

for ii=1:lx
	for jj=1:ly
		if(nxy(ii,jj) ~= 0)
			ixy = ixy + nxy(ii,jj)*log(n*nxy(ii,jj)/(nx(ii)*ny(jj))) ;
		end
	end
end

if (hx*hy==0)
	c=0;
else
	c = ixy/sqrt(hx*hy);
end
