function printmodel(model,sslapps,file)
%	Generate C files containing the model
%
%	Description
%	printmodel(MODEL, SSLAPPS, [FILE]) takes as input a model (obtained from modelBehaviors)
%		and writes the model in FILE.h and FILE.c (default: model.h and model.c)
%		SSLAPPS contains the list of SSL applications for instance {'ssl','tls'}
%

if nargin<2
	file='model';
end

hfile=sprintf('%s.h',file);
cfile=sprintf('%s.c',file);
fprintf('Model will be in %s and %s\n\n',hfile,cfile);

fid = fopen(hfile,'w');
fprintf(fid,'#define LABEL_NONE 100\n');
fprintf(fid,'#define LABEL_NOSYN 101\n');
fprintf(fid,'#define LABEL_OUTOFSEQ 102\n');
fprintf(fid,'#define LABEL_PARSED 127\n\n');
fprintf(fid,'typedef struct _model_t{\n');
fprintf(fid,'\tint nbpackets;\n');
fprintf(fid,'\tint nbclusters;\n');
fprintf(fid,'\tint nbapplis;\n');
fprintf(fid,'\tchar applis[%d][20];\n',length(model.Applis));
fprintf(fid,'\tint SSLapplis[%d];\n',length(model.Applis));
fprintf(fid,'\tint nbports;\n');
fprintf(fid,'\tint knownports[%d];\n',length(model.knownports));
fprintf(fid,'\tint SSL_nbports;\n');
fprintf(fid,'\tint SSL_knownports[%d];\n',length(model.SSL_knownports));

fprintf(fid,'\tstruct clust {\n');

fprintf(fid,'\t\tint labelDom;\n');
fprintf(fid,'\t\tint DominantUnStd;\n');
fprintf(fid,'\t\tfloat cst;\n');
fprintf(fid,'\t\tint appFromPort[%d];\n',length(model.knownports));
fprintf(fid,'\t\tint SSL_appFromPort[%d];\n',length(model.SSL_knownports));
fprintf(fid,'\t\tfloat center[%d];\n',model.pkts);
fprintf(fid,'\t\tfloat covar[%d];\n',model.pkts);
fprintf(fid,'\t} clusters[%d];\n',model.clusters);

fprintf(fid,'} model_t;\n\n');
fprintf(fid,'extern const model_t model;\n');

fclose(fid);
fid = fopen(cfile,'w');

fprintf(fid,'#include "model.h"\n\n');
fprintf(fid,'const model_t model=\t{%d,%d,%d,\n',model.pkts,model.clusters,length(model.Applis));

fprintf(fid,'\t{"%s"',model.Applis{1});
for i=2:length(model.Applis)
	fprintf(fid,',"%s"',model.Applis{i});
end
fprintf(fid,'},\n');

fprintf(fid,'\t{%d',sum(strcmp(model.Applis(1),sslapps)));
for i=2:length(model.Applis)
	fprintf(fid,',%d',sum(strcmp(model.Applis(i),sslapps)));
end
fprintf(fid,'},\n');


fprintf(fid,'\t%d,{%d',length(model.knownports),model.knownports(1));
for i=2:length(model.knownports)
	fprintf(fid,',%d',model.knownports(i));
end
fprintf(fid,'},\n');

fprintf(fid,'\t%d,{%d',length(model.SSL_knownports),model.SSL_knownports(1));
for i=2:length(model.SSL_knownports)
	fprintf(fid,',%d',model.SSL_knownports(i));
end
fprintf(fid,'},\n');

fprintf(fid,'\t{\n');
for i=1:model.clusters
	fprintf(fid,'\t\t{%d,%d,%f',model.labelDom(i),model.DominantUnStd(i),-model.pkts/2*log(2*pi)-1/2*sum(log(model.gmm.covars(i,:))));
	for j=1:length(model.knownports)
		fprintf(fid,',%d',model.appFromPort(i,j));
	end
	for j=1:length(model.SSL_knownports)
		fprintf(fid,',%d',model.SSL_appFromPort(i,j));
	end
	fprintf(fid,',\n\t\t\t{%f',model.gmm.centres(i,1));
	for j=2:model.pkts
		fprintf(fid,',%f',model.gmm.centres(i,j));
	end
	fprintf(fid,'},\n\t\t\t{%f',model.gmm.covars(i,1));
	for j=2:model.pkts
		fprintf(fid,',%f',model.gmm.covars(i,j));
	end
	if(i<model.clusters)
		fprintf(fid,'}},\n',model.gmm.covars(i,1));
	else
		fprintf(fid,'}}\n',model.gmm.covars(i,1));
	end
end
fprintf(fid,'\t}};\n');

fclose(fid);
end
